# Simple way to send sms through Ozeki Phone System XE or Ozeki NG SMS Gateway.

class SMS

  require 'uri'
  require 'net/http'

  # Class method to send an SMS message through Ozeki NG SMS Gateway
  def self.ng_send_sms ng_ip_address, username, password, to, message, port=9501, from=nil
    to = URI::encode(to)
    message = URI::encode(message)
    from ||= ""
    uri = URI "http://#{ng_ip_address}:#{port}/api?action=sendmessage&username=#{username}&password=#{password}&originator=#{from}&recipient=#{to}&messagetype=SMS:TEXT&messagedata=#{message}"
    Response.create Net::HTTP.get uri
  end
  
  # Class method to send an SMS message through Ozeki Phone System XE
  def self.ops_send_sms ops_ip_address, api_extension, to, message, http_api_service_port=7780, from=nil, delivery_report_url=nil, username=nil, password=nil
    to = URI::encode(to)
    message = URI::encode(message)
    
    from ||= ""
    from = URI::encode(from)
    delivery_report_url ||= "" 
    delivery_report_url = URI::encode(delivery_report_url)
    http_api_service_port ||= 7780

    SMS.execute_query "http://#{ops_ip_address}:#{http_api_service_port}/?Command=SendSms&ApiExtension=#{api_extension}&Sender=#{from}&Recipient=#{to}&Message=#{message}&DeliveryReportURL=#{delivery_report_url}", username, password
  end
  
  private
  def self.execute_query query, username, password
    if (username != nil) && (password != nil)
      query += "&username=#{username}&password=#{password}"
    end

    uri = URI query 
    Response.create Net::HTTP.get uri   
  end
end

class Response
  
  # code: Get the status code of the returned response
  # message: Get the status message of the returned response
  attr_accessor :code, :message

  # User friendly string format
  def to_s
     message + " (" + code + ")"
  end
  
  private
  def initialize code=nil, message=nil
    @code = code || ""
    @message = message || ""
  end
  
  private
  def self.create response
    lines = response.split(/[\r\n]+/)
    
    resp = Response.new
  
    lines.each do |line|
      if (((start_index = line.index('<Code>')) != nil) && (end_index = line.index('</Code>')) != nil)
        resp.code = line[start_index + 6, end_index - start_index - 6]
      elsif (((start_index = line.index('<statuscode>')) != nil) && (end_index = line.index('</statuscode>')) != nil)
        resp.code = line[start_index + 12, end_index - start_index - 12]
      elsif (((start_index = line.index('<Message>')) != nil) && (end_index = line.index('</Message>')) != nil)
        resp.message = line[start_index + 9, end_index - start_index - 9]
      elsif (((start_index = line.index('<statusmessage>')) != nil) && (end_index = line.index('</statusmessage>')) != nil)
        resp.message = line[start_index + 15, end_index - start_index - 15]
      end
    end

    if (resp.code != "") && (resp.message != "")
      return resp
    else
      return response
    end
  end
end